import django_tables2 as tables
from django.urls import reverse
from django.utils.safestring import mark_safe

from frappe.models import Document
from lib.tables import StrippedTable


class DocumentTable(StrippedTable):
    annee_filiere = tables.Column(accessor="matiere__filiere__annee")
    filiere = tables.Column(accessor="matiere__filiere__nom")
    matiere = tables.Column(accessor="matiere__nom")
    fichier = tables.Column(accessor="fichiers")
    auteur = tables.Column(accessor="auteur", linkify=True)
    edit = tables.Column(accessor="auteur", verbose_name="")

    class Meta(StrippedTable.Meta):
        model = Document
        fields = ("annee_filiere", "filiere", "matiere", "nom", "annee", "fichier", "auteur", "edit")

    def render_annee(self, value):
        return str(value) + "/" + str(value + 1)

    def render_fichier(self, record):
        render_str = ""
        for doc_fichier in record.fichiers():
            render_str += f"<a href='{doc_fichier.fichier.url}'>{doc_fichier}</a><br>"
        return mark_safe(render_str)

    def render_auteur(self, value):
        return value.get_full_name()

    def render_edit(self, record):
        render_str = f"""
        <a href="{reverse('gestion:frappe:documents_editer', args=[record.pk])}" class="btn btn-warning text-white btn-sm">
        <i class="fas fa-pencil-alt"></i></a>
        <a href="{reverse('gestion:frappe:documents_supprimer', args=[record.pk])}" class="btn btn-danger btn-sm">
        <i class="fas fa-trash-alt"></i></a>
        """
        return mark_safe(render_str)
